<!-- 塔管理 -->
<template>
  <div class="app-container">
     <el-row :gutter="20">
       <el-col :span="showMap ? 12 : 24" :xs="24">
        <AppTable ref="AppTable" selection :showDeptSearch="false" :url="'tower/model/list'" :tableColumns="tableColumns"
          :tableFilter="tableFilter">
          <template #operatorBox="{ row }">
            <el-button type="primary" plain icon="el-icon-plus" size="mini"
              @click="handleAdd">新增模型</el-button>
          </template>
          <template #modelType="{ row }">
            <DictTag :options="dict.type.model_type" :value="row.modelType"></DictTag>
          </template>
          <template #operator="{ row }">
            <el-button size="mini" type="text" icon="el-icon-edit"
              @click.stop="handleUpdate(row)">修改</el-button>
            <el-button size="mini" type="text" icon="el-icon-delete"
              @click.stop="handleDelete(row)">删除</el-button>
          </template>
        </AppTable>
      </el-col>    
       <el-col :span="12" :xs="24" v-if="showMap">   
          <CesiumMap ></CesiumMap>
       </el-col>
     </el-row>
   
    <modelDialog ref="modelDialog" @on-submit="$refs.AppTable.getData()" :model_type="dict.type.model_type"></modelDialog>
  </div>
</template>

<script>
import modelDialog from './components/modelDialog.vue';
import CesiumMap from "../../../utils/components/cesium-map.vue";
export default {
  name: "towers",
  dicts: ['model_type'],
  components: {
    modelDialog,
    CesiumMap
  },
  data() {
    return {
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      tableColumns: [
        {
          label: '模型名称',
          prop: 'modelName'
        },
        {
          label: '模型类型',
           type: 'slot',
          slotName: 'modelType'
        },
        {
          label: '模型路径',
          prop: 'modelRoute'
        },
        {
          label: '操作',
          type: 'slot',
          slotName: 'operator',
          width: '330px'
        },
      ],
      tableFilter: [
        {
          title: '模型名称',
          placeholder: '请输入模型名称',
          fieldName: 'name',
          clearable: true,
          type: 'search',
        }
      ],
      showMap:false
    };
  },
  watch: {
  },
  created() {
  },
  mounted() {
  },
  methods: {
    // 添加数据
    handleAdd() {
      this.showMap  = false
      this.$refs.modelDialog.show()
    },
    // 更新数据
    handleUpdate(row) {
      const ids = row.id || this.ids
      this.$refs.modelDialog.show(ids)
    },
    // 删除数据
    handleDelete(row) {
      const ids = row.id || this.ids
      const name = row.modelName || ''
      this.$api.deleteByName('/tower/model', ids,name).then(res => {
        this.$refs.AppTable.getData()
      })
    },
    // 导出表格数据
    handleExport() {
      this.$refs.AppTable.exportExcel()
    },
    clickRow(row){
      console.log(row)
      // this.showMap =true
    },
  },
};
</script>

<style scoped>
.left-card {
  height: calc(100vh - 105px);
  overflow: auto;
}

.right-card {
  height: calc(100vh - 105px);
}
</style>
